@@ -3,7 +3,7 @@
 mkdir build
 cd build
 
-cmake .. \
+cmake ${CMAKE_ARGS} .. \
       -G "Ninja" \
       -DCMAKE_BUILD_TYPE=Release \
       -DCMAKE_PREFIX_PATH=$PREFIX -DCMAKE_INSTALL_PREFIX=$PREFIX \
@@ -12,4 +12,6 @@ cmake .. \
 
 cmake --build . --config Release
 cmake --build . --config Release --target install
+if [[ "${CONDA_BUILD_CROSS_COMPILATION}" != "1" ]]; then
 ctest -C Release -E "INTEGRATION|PERFORMANCE|REGRESSION" -VV
+fi
